@@ -1,18 +1,29 @@
 import json
 import requests
 import re
+import base64
 from bs4 import BeautifulSoup
-
+from datetime import datetime
 
 class sdk:
-    def __init__(self, brugernavn, adgangskode, skoleId):
-        self.brugernavn = brugernavn
-        self.adgangskode = adgangskode
-        self.skoleId = skoleId
-
+    def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
         self.session = requests.session()
 
-        self.login()
+        if base64Cookie == None:
+            self.brugernavn = brugernavn
+            self.adgangskode = adgangskode
+            self.skoleId = skoleId
+
+            self.login()
+        else:
+            cookie = json.loads(base64.b64decode(base64Cookie))
+            self.skoleId = cookie["LastLoginExamno"]
+
+            for identifier, value in cookie.items():
+                self.session.cookies.set(identifier, value, domain="lectio.dk")
+
+            self.elevId = self.fåSkoleId()
+
 
     def login(self):
         headers = {
@@ -63,8 +74,7 @@ class sdk:
             'upgrade-insecure-requests': '1',
             'user-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.0.0 Safari/537.36',
         }
-        resp = self.session.post(f"https://www.lectio.dk/lectio/{self.skoleId}/login.aspx", data=payload,
-                                 headers=headers)
+        resp = self.session.post(f"https://www.lectio.dk/lectio/{self.skoleId}/login.aspx", data=payload, headers=headers)
         soup = BeautifulSoup(resp.text, "html.parser")
 
         successful = False
@@ -76,16 +86,84 @@ class sdk:
         if not successful:
             raise Exception("Kunne ikke finde elev id. Rapporter venligst dette på Github")
 
+    def fåSkoleId(self):
+        resp = self.session.get("https://www.lectio.dk/lectio/681/forside.aspx")
+        soup = BeautifulSoup(resp.text, "html.parser")
+
+        for meta in soup.find_all({"meta": {"name": "msapplication-starturl"}}):
+            if f"/lectio/{self.skoleId}/forside.aspx?" in str(meta.get("content")):
+                return meta.get("content").split("?elevid=")[1]
+
+        raise Exception("Kunne ikke finde elev id. Rapporter venligst dette på Github")
+
+
+    def lektier(self, elevId=None):
+        if elevId == None:
+            elevId = self.elevId
+
+        resp = self.session.get(f"https://www.lectio.dk/lectio/681/material_lektieoversigt.aspx?elevid={elevId}")
+
+        soup = BeautifulSoup(resp.text, "html.parser")
+
+        lektier = []
+
+        renameDictionary = {
+            "Lærere": "Lærer",
+            "Lokaler": "Lokale"
+        }
+
+        for tr in soup.find_all("tr"):
+            modul = tr.find("a", class_="s2skemabrik")
+            modulDetaljer = modul["data-additionalinfo"].split("\n\n")[0].split("\n")
+
+            modulDict = {
+                "navn": None,
+                "tidspunkt": None,
+                "hold": None,
+                "lærer": None,
+                "lokale": None,
+                "absid": re.search('absid=[0-9]+', modul["href"]).group().replace("absid=", "")
+            }
+            for modulDetalje in modulDetaljer:
+                if (value := ": ".join(modulDetalje.split(": ")[1:])) != "":
+                    if (navn := modulDetalje.split(": ")[0]) in renameDictionary:
+                        navn = renameDictionary[navn]
+
+                    modulDict[navn.lower()] = value
+                else:
+                    try:
+                        int(datetime.strptime(modulDetalje.split(": ")[0].split(" til")[0],
+                                              "%d/%m-%Y %H:%M").timestamp())
+                        modulDict["tidspunkt"] = modulDetalje
+                    except Exception:
+                        modulDict["navn"] = modulDetalje.split(": ")[0]
+
+            lektie = {
+                "dato": tr.find("th").get("b"),
+                "aktivitet": modulDict,
+                "note": tr.find_all("td")[1].text,
+                "lektier": {
+                    "beskrivelse": tr.find_all("a")[1].text,
+                    "link": tr.find_all("a")[1].get("href")
+                }
+            }
+
+            lektier.append(lektie)
+
+        return lektier
+
     def skema(self, retry=False, uge=None, år=None, elevId=None):
         if elevId == None:
             elevId = self.elevId
 
         if uge == None and år == None:
-            resp = self.session.get(
-                f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?type=elev&elevid={elevId}")
+            resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?type=elev&elevid={elevId}")
         elif uge != None and år != None:
-            resp = self.session.get(
-                f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?type=elev&elevid={elevId}&week={uge}{år}")
+            uge = str(uge)
+            år = str(år)
+            if len(uge) == 1:
+                uge = "0" + uge
+            resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?type=elev&elevid={elevId}&week={uge}{år}")
         else:
             raise Exception("Enten skal hverken uge og år være i brug ellers skal både uge og år være i brug")
 
@@ -94,27 +172,45 @@ class sdk:
         successful = False
         skema = []
         i = 0
+
+        renameDictionary = {
+            "Lærere": "Lærer",
+            "Lokaler": "Lokale"
+        }
+
         for dag in soup.find_all("div", class_="s2skemabrikcontainer"):
             if i != 0:
                 dag = BeautifulSoup(str(dag), "html.parser")
                 for modul in dag.find_all("a", class_="s2skemabrik"):
-                    modulDetailer = modul["data-additionalinfo"].split("\n\n")[0].split("\n")
+                    modulDetaljer = modul["data-additionalinfo"].split("\n\n")[0].split("\n")
 
                     modulDict = {
-                        "tidspunkt": modulDetailer[-4],
-                        "hold": modulDetailer[-3].replace("Hold: ", ""),
-                        "lærer": modulDetailer[-2].replace("Lærere: ", "").replace("Lærer: ", ""),
-                        "lokale": modulDetailer[-1].replace("Lokale: ", "")
+                        "navn": None,
+                        "tidspunkt": None,
+                        "hold": None,
+                        "lærer": None,
+                        "lokale": None,
+                        "absid": re.search('absid=[0-9]+', modul["href"]).group().replace("absid=", ""),
+                        "andet": None
                     }
+                    for modulDetalje in modulDetaljer:
+                        if (value := ": ".join(modulDetalje.split(": ")[1:])) != "":
+                            if (navn := modulDetalje.split(": ")[0]) in renameDictionary:
+                                navn = renameDictionary[navn]
+
+                            modulDict[navn.lower()] = value
+                        else:
+                            try:
+                                int(datetime.strptime(modulDetalje.split(": ")[0].split(" til")[0], "%d/%m-%Y %H:%M").timestamp())
+                                modulDict["tidspunkt"] = modulDetalje
+                            except Exception:
+                                modulDict["navn"] = modulDetalje.split(": ")[0]
 
                     try:
                         modulDict["andet"] = modul["data-additionalinfo"].split("\n\n")[1]
                     except Exception:
-                        modulDict["andet"] = None
                         pass
 
-                    modulDict["absid"] = re.search('absid=[0-9]+', modul["href"]).group().replace("absid=", "")
-
                     skema.append(modulDict)
             i += 1
 
@@ -129,6 +225,16 @@ class sdk:
         else:
             return False
 
+    def fåElev(self, elevId):
+        resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/SkemaNy.aspx?type=elev&elevid={elevId}")
+        soup = BeautifulSoup(resp.text, "html.parser")
+
+        elev = {
+            "navn": soup.find("div", {"class": "maintitle"}).text.replace(" - Skema", ""),
+            "billede": soup.find("img", {"id": "s_m_HeaderContent_picctrlthumbimage"}).get("src")
+        }
+
+        return elev
     def elever(self, forbogstav, retry=False):
         elever = []
 
